Commit 736f53f88d1f1b754e07e55793580229babe9e9c

Con Kolivas 2014-02-22T11:35:06

Increase to 25 nonce ranges on icarus fail detect.

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
diff --git a/driver-icarus.c b/driver-icarus.c
index 94acad0..6ab6f3d 100644
--- a/driver-icarus.c
+++ b/driver-icarus.c
@@ -667,11 +667,9 @@ static void set_timing_mode(int this_option_offset, struct cgpu_info *icarus)
 			timing_mode_str(info->timing_mode),
 			info->read_time, info->read_time_limit, info->Hs);
 
-	/* Set the time to detect a dead device to 10 nonce ranges or 1 minute,
-	 * whichever is larger. */
-	fail_time = info->Hs * 0xffffffffull * 10;
-	if (fail_time < 60)
-		fail_time = 60;
+	/* Set the time to detect a dead device to 25 full nonce ranges. */
+	fail_time = info->Hs * 0xffffffffull * 25.0;
+	/* Integer accuracy is definitely enough. */
 	info->fail_time = fail_time;
 }